# perspective-ray-dashboard
A scalable ray dashboard built with perspective

[![Build Status](https://github.com/perspective-community/perspective-ray-dashboard/workflows/Build%20Status/badge.svg?branch=main)](https://github.com/perspective-community/perspective-ray-dashboard/actions?query=workflow%3A%22Build+Status%22)
[![codecov](https://codecov.io/gh/perspective-community/perspective-ray-dashboard/branch/main/graph/badge.svg)](https://codecov.io/gh/perspective-community/perspective-ray-dashboard)
[![PyPI](https://img.shields.io/pypi/l/perspective-ray-dashboard.svg)](https://pypi.python.org/pypi/perspective-ray-dashboard)
[![PyPI](https://img.shields.io/pypi/v/perspective-ray-dashboard.svg)](https://pypi.python.org/pypi/perspective-ray-dashboard)


[![](https://raw.githubusercontent.com/perspective-community/perspective-ray-dashboard/main/docs/demo.gif)](Demo.ipynb)
